package net.wanji.web.controller.scheme;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.databus.bo.CrossIdBO;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.web.dto.SaveLaneInfoDTO;
import net.wanji.web.service.scheme.impl.CrossConfigServiceImpl;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.ws.rs.core.MediaType;

/**
 * @author Kent HAN
 * @date 2022/12/20 10:14
 */
@Api(value = "CrossConfigController", description = "方案管理-路口配置、灯组配置")
@RequestMapping("/crossConfig")
@RestController
public class CrossConfigController {


    private final CrossConfigServiceImpl crossConfigService;

    public CrossConfigController(CrossConfigServiceImpl crossConfigService) {
        this.crossConfigService = crossConfigService;
    }

    @AspectLog(description = "保存渠化配置/灯组设置、车道配置", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "保存渠化配置/灯组设置、车道配置", notes = "保存渠化配置/灯组设置、车道配置", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/saveLaneInfo",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject saveLaneInfo(@RequestBody SaveLaneInfoDTO saveLaneInfoDTO) {
        crossConfigService.saveLaneInfo(saveLaneInfoDTO);
        return JsonViewObject.newInstance().success();
    }

    @AspectLog(description = "渠化配置/灯组设置、车道配置列表", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "渠化配置/灯组设置、车道配置列表", notes = "渠化配置/灯组设置、车道配置列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/listLaneInfo",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveLaneInfoDTO.class),
    })
    public JsonViewObject listLaneInfo(@RequestBody @Valid CrossIdBO crossIdBO) {
        SaveLaneInfoDTO saveLaneInfoDTO = crossConfigService.listLaneInfo(crossIdBO);
        return JsonViewObject.newInstance().success(saveLaneInfoDTO);
    }
}
